@@ -3,13 +3,13 @@ from typing import overload, Optional, Union, Dict, List, Tuple, Callable, TYPE_
 
 import numpy as np
 
-from ...math import ndarray
-from ...score import NamedScore
+from docarray.math import ndarray
+from docarray.score import NamedScore
 
 if TYPE_CHECKING:
-    from ...typing import T, ArrayType
+    from docarray.typing import T, ArrayType
 
-    from ... import Document, DocumentArray
+    from docarray import Document, DocumentArray
 
 
 class FindMixin:
@@ -87,22 +87,29 @@ class FindMixin:
 
     def find(
         self: 'T',
-        query: Union['DocumentArray', 'Document', 'ArrayType', Dict, str, List[str]],
+        query: Union[
+            'DocumentArray', 'Document', 'ArrayType', Dict, str, List[str], None
+        ] = None,
         metric: Union[
             str, Callable[['ArrayType', 'ArrayType'], 'np.ndarray']
         ] = 'cosine',
         limit: Optional[Union[int, float]] = 20,
         metric_name: Optional[str] = None,
         exclude_self: bool = False,
+        filter: Optional[Dict] = None,
         only_id: bool = False,
         index: str = 'text',
         **kwargs,
     ) -> Union['DocumentArray', List['DocumentArray']]:
         """Returns matching Documents given an input query.
         If the query is a `DocumentArray`, `Document` or `ArrayType`, exhaustive or approximate nearest neighbor search
-        will be performed depending on whether the storage backend supports ANN.
-        If the query is a `dict` object, Documents will be filtered according to DocArray's query language and all
-        matching Documents that match the filter will be returned.
+        will be performed depending on whether the storage backend supports ANN. Furthermore, if filter is not None,
+        pre-filtering will be applied along with vector search.
+        If the query is a `dict` object or, query is None and filter is not None, Documents will be filtered and all
+        matching Documents that match the filter will be returned. In this case, query (if it's dict) or filter will be
+        used for filtering. The object must follow the backend-specific filter format if the backend supports filtering
+        or DocArray's query language format. In the latter case, filtering will be applied in the client side not the
+        backend side.
         If the query is a string or list of strings, a search by text will be performed if the backend supports
         indexing and searching text fields. If not, a `NotImplementedError` will be raised.
 
@@ -112,6 +119,7 @@ class FindMixin:
         :param metric: the distance metric.
         :param exclude_self: if set, Documents in results with same ``id`` as the query values will not be
                         considered as matches. This is only applied when the input query is Document or DocumentArray.
+        :param filter: filter query used for pre-filtering or filtering
         :param only_id: if set, then returning matches will only contain ``id``
         :param index: if the query is a string, text search will be performed on the `index` field, otherwise, this
                       parameter is ignored. By default, the Document `text` attribute will be used for search,
@@ -122,25 +130,38 @@ class FindMixin:
         :return: a list of DocumentArrays containing the closest Document objects for each of the queries in `query`.
         """
 
-        from ... import Document, DocumentArray
+        from docarray import Document, DocumentArray
 
         if isinstance(query, dict):
-            return self._filter(query)
+            if filter is None:
+                return self._filter(query, limit=limit)
+            else:
+                raise ValueError(
+                    'filter and query cannot be both dict type, set only one for filtering'
+                )
+        elif query is None:
+            if isinstance(filter, dict):
+                return self._filter(filter, limit=limit)
+            else:
+                raise ValueError('filter must be dict when query is None')
+        elif isinstance(query, str) or (
+            isinstance(query, list) and isinstance(query[0], str)
+        ):
+            if filter is not None:
+                raise ValueError('cannot use filter with text search')
+            result = self._find_by_text(query, index=index, limit=limit, **kwargs)
+            if isinstance(query, str):
+                return result[0]
+            else:
+                return result
+
+        # for all the rest, vector search will be performed
         elif isinstance(query, (DocumentArray, Document)):
 
             if isinstance(query, Document):
                 query = DocumentArray(query)
 
             _query = query.embeddings
-        elif isinstance(query, str) or (
-            isinstance(query, list) and isinstance(query[0], str)
-        ):
-            result = self._find_by_text(query, index=index, limit=limit, **kwargs)
-
-            if len(result) == 1:
-                return result[0]
-            else:
-                return result
         else:
             _query = query
 
@@ -170,6 +191,7 @@ class FindMixin:
 
         _result = self._find(
             _query,
+            filter=filter,
             **kwargs,
         )
 
@@ -206,6 +228,7 @@ class FindMixin:
                     if len(matches) >= _limit:
                         break
                 result.append(matches)
+
         else:
             raise TypeError(
                 f'unsupported type `{type(_result)}` returned from `._find()`'
@@ -219,27 +242,29 @@ class FindMixin:
                 else:
                     result[i] = matches
 
-        if len(result) == 1:
-            return result[0]
-        else:
-            return result
+        # ensures query=np.array([1,2,3]) returns DocumentArray not list with 1 DocumentArray
+        if n_dim == 1:
+            result = result[0]
+
+        return result
 
     @abc.abstractmethod
     def _find(
-        self, query: 'ArrayType', limit: int, **kwargs
+        self, query: 'ArrayType', limit: int, filter: Optional[Dict] = None, **kwargs
     ) -> Tuple['np.ndarray', 'np.ndarray']:
         raise NotImplementedError
 
     def _filter(
         self,
-        query: Dict,
+        query: Union[Dict, List[Dict]],
+        limit: Optional[Union[int, float]] = 20,
     ) -> 'DocumentArray':
         """Returns a subset of documents by filtering by the given query.
 
         :return: a `DocumentArray` containing the `Document` objects for matching with the query.
         """
-        from ... import DocumentArray
-        from ..queryset import QueryParser
+        from docarray import DocumentArray
+        from docarray.array.queryset import QueryParser
 
         if query:
             parser = QueryParser(query)
