@@ -1,9 +1,8 @@
-from typing import Union, Iterable, Sequence
+from typing import Union, Iterable
 
-from ..base.seqlike import BaseSequenceLikeMixin
-from .... import Document
-
-from ...memory import DocumentArrayInMemory
+from docarray.array.storage.base.seqlike import BaseSequenceLikeMixin
+from docarray.array.memory import DocumentArrayInMemory
+from docarray import Document
 
 
 class SequenceLikeMixin(BaseSequenceLikeMixin):
@@ -33,21 +32,9 @@ class SequenceLikeMixin(BaseSequenceLikeMixin):
             and self._config == other._config
         )
 
-    def __bool__(self):
-        """To simulate ```l = []; if l: ...```
-
-        :return: returns true if the length of the array is larger than 0
-        """
-        return len(self) > 0
-
     def __repr__(self):
         return f'<DocumentArray[AnnLite] (length={len(self)}) at {id(self)}>'
 
-    def __add__(self, other: Union['Document', Sequence['Document']]):
-        v = type(self)(self)
-        v.extend(other)
-        return v
-
     def __contains__(self, x: Union[str, 'Document']):
         if isinstance(x, str):
             return self._annlite.get_doc_by_id(x) is not None
