@@ -27,7 +27,7 @@ from docarray.helper import dataclass_from_dict, random_identity
 from docarray.math.helper import EPSILON
 
 if TYPE_CHECKING:
-    from ....typing import DocumentArraySourceType, ArrayType
+    from docarray.typing import DocumentArraySourceType, ArrayType
 
 
 @dataclass
@@ -88,8 +88,7 @@ class BackendMixin(BaseBackendMixin):
         self._config = config
         self._persist = bool(self._config.collection_name)
 
-        if self._config.columns is None:
-            self._config.columns = []
+        self._config.columns = self._normalize_columns(self._config.columns)
 
         self._config.collection_name = (
             self.__class__.__name__ + random_identity()
@@ -185,7 +184,7 @@ class BackendMixin(BaseBackendMixin):
         if embedding is None:
             embedding = np.random.rand(self.n_dim)
         else:
-            from ....math.ndarray import to_numpy_array
+            from docarray.math.ndarray import to_numpy_array
 
             embedding = to_numpy_array(embedding)
 
